==> 0.0.13.tar.gz: lib/src/model/User.dart <==
class User extends Object {
  late int id;
  late Map<String, dynamic> attributes;
  late String name;
  late String login;
  late String email;
  late String phone;
  late bool readonly;
  late bool administrator;
  late String map;
  late double latitude;
  late double longitude;
  late int zoom;
  late bool twelveHourFormat;
  late String coordinateFormat;
  late bool disabled;
  late String expirationTime;
  late int deviceLimit;
  late int userLimit;
  late bool deviceReadonly;
  late String token;
  late bool limitCommands;
  late String poiLayer;
  late String password;

  User(
      {id,
      attributes,
      name,
      login,
      email,
      phone,
      readonly,
      administrator,
      map,
      latitude,
      longitude,
      zoom,
      twelveHourFormat,
      coordinateFormat,
      disabled,
      expirationTime,
      deviceLimit,
      userLimit,
      deviceReadonly,
      token,
      limitCommands,
      poiLayer,
      password});

  User.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    attributes = json["attributes"];
    name = json["name"];
    login = json["login"];
    email = json["email"];
    phone = json["phone"];
    readonly = json["readonly"];
    administrator = json["administrator"];
    map = json["map"];
    latitude = json["latitude"];
    longitude = json["longitude"];
    zoom = json["zoom"];
    twelveHourFormat = json["twelveHourFormat"];
    coordinateFormat = json["coordinateFormat"];
    disabled = json["disabled"];
    expirationTime = json["expirationTime"];
    deviceLimit = json["deviceLimit"];
    userLimit = json["userLimit"];
    deviceReadonly = json["deviceReadonly"];
    token = json["token"];
    limitCommands = json["limitCommands"];
    poiLayer = json["poiLayer"];
    password = json["password"];
  }

  Map<String, dynamic> toJson() => {
        'id': id,
        'attributes': attributes,
        'name': name,
        'login': login,
        'email': email,
        'phone': phone,
        'readonly': readonly,
        'administrator': administrator,
        'map': map,
        'latitude': latitude,
        'longitude': longitude,
        'zoom': zoom,
        'twelveHourFormat': twelveHourFormat,
        'coordinateFormat': coordinateFormat,
        'disabled': disabled,
        'expirationTime': expirationTime,
        'deviceLimit': deviceLimit,
        'userLimit': userLimit,
        'deviceReadonly': deviceReadonly,
        'token': token,
        'limitCommands': limitCommands,
        'poiLayer': poiLayer,
        'password': password
      };
}

==> 0.0.16.tar.gz: lib/src/model/User.dart <==
class User extends Object {
  late int id;
  late Map<String, dynamic> attributes;
  late String name;
  late String email;
  late String phone;
  late bool readonly;
  late bool administrator;
  late String map;
  late double latitude;
  late double longitude;
  late int zoom;
  late bool twelveHourFormat;
  late String coordinateFormat;
  late bool disabled;
  String? expirationTime;
  late int deviceLimit;
  late int userLimit;
  late bool deviceReadonly;
  late String token;
  late bool limitCommands;
  late String poiLayer;
  late String password;

  User(
      {id,
      attributes,
      name,
      login,
      email,
      phone,
      readonly,
      administrator,
      map,
      latitude,
      longitude,
      zoom,
      twelveHourFormat,
      coordinateFormat,
      disabled,
      expirationTime,
      deviceLimit,
      userLimit,
      deviceReadonly,
      token,
      limitCommands,
      poiLayer,
      password});

  User.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    attributes = json["attributes"];
    name = json["name"];
    email = json["email"];
    phone = json["phone"];
    readonly = json["readonly"];
    administrator = json["administrator"];
    map = json["map"];
    latitude = json["latitude"];
    longitude = json["longitude"];
    zoom = json["zoom"];
    twelveHourFormat = json["twelveHourFormat"];
    coordinateFormat = json["coordinateFormat"];
    disabled = json["disabled"];
    expirationTime = json["expirationTime"];
    deviceLimit = json["deviceLimit"];
    userLimit = json["userLimit"];
    deviceReadonly = json["deviceReadonly"];
    token = json["token"];
    limitCommands = json["limitCommands"];
    poiLayer = json["poiLayer"];
    password = json["password"];
  }

  Map<String, dynamic> toJson() => {
        'id': id,
        'attributes': attributes,
        'name': name,
        'email': email,
        'phone': phone,
        'readonly': readonly,
        'administrator': administrator,
        'map': map,
        'latitude': latitude,
        'longitude': longitude,
        'zoom': zoom,
        'twelveHourFormat': twelveHourFormat,
        'coordinateFormat': coordinateFormat,
        'disabled': disabled,
        'expirationTime': expirationTime,
        'deviceLimit': deviceLimit,
        'userLimit': userLimit,
        'deviceReadonly': deviceReadonly,
        'token': token,
        'limitCommands': limitCommands,
        'poiLayer': poiLayer,
        'password': password
      };
}
